@@ -1,33 +1,37 @@
-if (!identical(Sys.getenv("NOT_CRAN"), "true")) return()
-
-out <- capture.output(
-  suppressMessages(
-    cmds_mdm_lcdm <- measr_dcm(
-      data = mdm_data, missing = NA, qmatrix = mdm_qmatrix,
-      resp_id = "respondent", item_id = "item", type = "lcdm",
-      method = "mcmc", seed = 63277, backend = "cmdstanr",
-      iter_sampling = 500, iter_warmup = 1000, chains = 2,
-      parallel_chains = 2,
-      prior = c(prior(uniform(-15, 15), class = "intercept"),
-                prior(uniform(0, 15), class = "maineffect")))
+if (!identical(Sys.getenv("NOT_CRAN"), "true")) {
+  skip("No MCMC on CRAN")
+} else {
+  out <- capture.output(
+    suppressMessages(
+      cmds_mdm_lcdm <- measr_dcm(
+        data = mdm_data, missing = NA, qmatrix = mdm_qmatrix,
+        resp_id = "respondent", item_id = "item", type = "lcdm",
+        method = "mcmc", seed = 63277, backend = "cmdstanr",
+        iter_sampling = 500, iter_warmup = 1000, chains = 2,
+        parallel_chains = 2,
+        prior = c(prior(uniform(-15, 15), class = "intercept"),
+                  prior(uniform(0, 15), class = "maineffect")))
+    )
   )
-)
 
-out <- capture.output(
-  suppressMessages(
-    cmds_mdm_dina <- measr_dcm(
-      data = mdm_data, missing = NA, qmatrix = mdm_qmatrix,
-      resp_id = "respondent", item_id = "item", type = "dina",
-      attribute_structure = "independent",
-      method = "mcmc", seed = 63277, backend = "rstan",
-      iter = 1500, warmup = 1000, chains = 2,
-      cores = 2,
-      prior = c(prior(beta(5, 17), class = "slip"),
-                prior(beta(5, 17), class = "guess")))
+  out <- capture.output(
+    suppressMessages(
+      cmds_mdm_dina <- measr_dcm(
+        data = mdm_data, missing = NA, qmatrix = mdm_qmatrix,
+        resp_id = "respondent", item_id = "item", type = "dina",
+        attribute_structure = "independent",
+        method = "mcmc", seed = 63277, backend = "rstan",
+        iter = 1500, warmup = 1000, chains = 2,
+        cores = 2,
+        prior = c(prior(beta(5, 17), class = "slip"),
+                  prior(beta(5, 17), class = "guess")))
+    )
   )
-)
+}
 
 test_that("as_draws works", {
+  skip_on_cran()
+
   draws <- as_draws(cmds_mdm_dina)
   expect_s3_class(draws, "draws_array")
 
@@ -48,6 +52,8 @@ test_that("as_draws works", {
 })
 
 test_that("get_mcmc_draws works as expected", {
+  skip_on_cran()
+
   test_draws <- get_mcmc_draws(cmds_mdm_lcdm)
   expect_equal(posterior::ndraws(test_draws), 1000)
   expect_equal(posterior::nvariables(test_draws), 10)
@@ -60,6 +66,8 @@ test_that("get_mcmc_draws works as expected", {
 })
 
 test_that("log_lik is calculated correctly", {
+  skip_on_cran()
+
   log_lik <- prep_loglik_array(cmds_mdm_lcdm)
 
   # expected value from 2-class LCA fit in Mplus
@@ -67,6 +75,8 @@ test_that("log_lik is calculated correctly", {
 })
 
 test_that("loo and waic work", {
+  skip_on_cran()
+
   err <- rlang::catch_cnd(loo(rstn_dina))
   expect_s3_class(err, "error_bad_method")
   expect_match(err$message, "`method = \"mcmc\"`")
@@ -83,6 +93,8 @@ test_that("loo and waic work", {
 })
 
 test_that("loo and waic can be added to model", {
+  skip_on_cran()
+
   err <- rlang::catch_cnd(measr_extract(cmds_mdm_lcdm, "loo"))
   expect_s3_class(err, "rlang_error")
   expect_match(err$message, "LOO criterion must be added")
@@ -108,9 +120,14 @@ test_that("loo and waic can be added to model", {
 
   expect_identical(measr_extract(lw_model, "loo"), lw_model$criteria$loo)
   expect_identical(measr_extract(lw_model, "waic"), lw_model$criteria$waic)
+
+  expect_identical(lw_model$criteria$loo, loo(lw_model))
+  expect_identical(lw_model$criteria$waic, waic(lw_model))
 })
 
 test_that("model comparisons work", {
+  skip_on_cran()
+
   err <- rlang::catch_cnd(loo_compare(cmds_mdm_lcdm, cmds_mdm_dina))
   expect_s3_class(err, "error_missing_criterion")
   expect_match(err$message, "does not contain a precomputed")
@@ -144,6 +161,8 @@ test_that("model comparisons work", {
 })
 
 test_that("ppmc works", {
+  skip_on_cran()
+
   test_ppmc <- fit_ppmc(cmds_mdm_lcdm, model_fit = character(),
                         item_fit = character())
   expect_equal(test_ppmc, list())
@@ -156,8 +175,10 @@ test_that("ppmc works", {
   expect_s3_class(test_ppmc$model_fit$raw_score, "tbl_df")
   expect_equal(nrow(test_ppmc$model_fit$raw_score), 1L)
   expect_equal(colnames(test_ppmc$model_fit$raw_score),
-               c("obs_chisq", "ppmc_mean", "2.5%", "97.5%", "samples", "ppp"))
-  expect_equal(length(test_ppmc$model_fit$raw_score$samples[[1]]), 100)
+               c("obs_chisq", "ppmc_mean", "2.5%", "97.5%", "rawscore_samples",
+                 "chisq_samples", "ppp"))
+  expect_equal(nrow(test_ppmc$model_fit$raw_score$rawscore_samples[[1]]), 100)
+  expect_equal(length(test_ppmc$model_fit$raw_score$chisq_samples[[1]]), 100)
 
   expect_equal(names(test_ppmc$item_fit), "conditional_prob")
   expect_s3_class(test_ppmc$item_fit$conditional_prob, "tbl_df")
@@ -209,6 +230,8 @@ test_that("ppmc works", {
 })
 
 test_that("ppmc extraction errors", {
+  skip_on_cran()
+
   err <- rlang::catch_cnd(measr_extract(cmds_mdm_lcdm, "ppmc_raw_score"))
   expect_s3_class(err, "rlang_error")
   expect_match(err$message, "Model fit information must be added")
@@ -232,6 +255,8 @@ test_that("ppmc extraction errors", {
 })
 
 test_that("model fit can be added", {
+  skip_on_cran()
+
   test_model <- cmds_mdm_dina
   expect_equal(test_model$fit, list())
 
@@ -245,10 +270,13 @@ test_that("model fit can be added", {
   expect_equal(names(test_model$fit$ppmc$item_fit$odds_ratio),
                c("item_1", "item_2", "obs_or", "ppmc_mean", "2.5%", "97.5%",
                  "samples", "ppp"))
+  expect_identical(test_model$fit$ppmc, fit_ppmc(test_model,
+                                                 model_fit = NULL,
+                                                 item_fit = "odds_ratio"))
 
   # nothing new does nothing
   test_model2 <- add_fit(test_model, method = "ppmc", model_fit = NULL,
-                        item_fit = NULL)
+                         item_fit = NULL)
   expect_identical(test_model, test_model2)
 
   # now add ppmc raw score and conditional probs -- other fit should persist
@@ -313,8 +341,11 @@ test_that("model fit can be added", {
 })
 
 test_that("respondent probabilities are correct", {
+  skip_on_cran()
+
   mdm_preds <- predict(cmds_mdm_lcdm, newdata = mdm_data,
                        resp_id = "respondent", summary = TRUE)
+  mdm_full_preds <- predict(cmds_mdm_lcdm, summary = FALSE)
 
   # dimensions are correct
   expect_equal(names(mdm_preds), c("class_probabilities",
@@ -328,6 +359,17 @@ test_that("respondent probabilities are correct", {
   expect_equal(nrow(mdm_preds$attribute_probabilities),
                nrow(mdm_data) * 1)
 
+  expect_equal(names(mdm_full_preds), c("class_probabilities",
+                                        "attribute_probabilities"))
+  expect_equal(colnames(mdm_full_preds$class_probabilities),
+               c("respondent", "[0]", "[1]"))
+  expect_equal(colnames(mdm_full_preds$attribute_probabilities),
+               c("respondent", "multiplication"))
+  expect_equal(nrow(mdm_full_preds$class_probabilities),
+               nrow(mdm_data))
+  expect_equal(nrow(mdm_full_preds$attribute_probabilities),
+               nrow(mdm_data))
+
   # extract works
   expect_equal(cmds_mdm_lcdm$respondent_estimates, list())
   err <- rlang::catch_cnd(measr_extract(cmds_mdm_lcdm, "class_prob"))
